@@ -53,6 +53,10 @@ class DeserializeFromJson(OrderingMixin, object):
                 errors.append({"error": error, "message": str(error)})
 
         if errors:
+            # Drop Python specific error classes in order to be able to better handle
+            # errors on front-end
+            for error in errors:
+                error["error"] = "ValidationError"
             raise BadRequest(errors)
 
         # We'll set the layout after the validation and even if there
