@@ -15,6 +15,7 @@ from plone.restapi.interfaces import ISerializeToJson
 from plone.restapi.interfaces import ISerializeToJsonSummary
 from plone.restapi.serializer.converters import json_compatible
 from plone.restapi.serializer.expansion import expandable_elements
+from plone.restapi.serializer.nextprev import NextPrevious
 from plone.rfc822.interfaces import IPrimaryFieldInfo
 from plone.supermodel.utils import mergedTaggedValueDict
 from Products.CMFCore.utils import getToolByName
@@ -67,6 +68,12 @@ class SerializeToJson(object):
             "is_folderish": False,
         }
 
+        # Insert next/prev information
+        nextprevious = NextPrevious(obj)
+        result.update(
+            {"previous_item": nextprevious.previous, "next_item": nextprevious.next}
+        )
+
         # Insert expandable elements
         result.update(expandable_elements(self.context, self.request))
 
@@ -90,12 +97,12 @@ class SerializeToJson(object):
                 # check for a special primary filed target
                 if name == primary_field_name:
                     target_adapter = queryMultiAdapter(
-                        (field, obj, self.request),
-                        IPrimaryFieldTarget)
+                        (field, obj, self.request), IPrimaryFieldTarget
+                    )
                     if target_adapter:
                         target = target_adapter()
                         if target:
-                            result['targetUrl'] = target
+                            result["targetUrl"] = target
 
         result["allow_discussion"] = getMultiAdapter(
             (self.context, self.request), name="conversation_view"
