@@ -1,9 +1,18 @@
 # -*- coding: utf-8 -*-
+from pkg_resources import get_distribution
+from pkg_resources import parse_version
 from plone.restapi.deserializer import json_body
 from plone.restapi.interfaces import ISerializeToJson
 from plone.restapi.services import Service
+from Products.CMFPlone.interfaces import IPloneSiteRoot
 from zope.component import getMultiAdapter
 
+zcatalog_version = get_distribution("Products.ZCatalog").version
+if parse_version(zcatalog_version) >= parse_version("5.1"):
+    SUPPORT_NOT_UUID_QUERIES = True
+else:
+    SUPPORT_NOT_UUID_QUERIES = False
+
 
 class QuerystringSearchPost(Service):
     """Returns the querystring search results given a p.a.querystring data.
@@ -28,7 +37,8 @@ class QuerystringSearchPost(Service):
         querybuilder = getMultiAdapter(
             (self.context, self.request), name="querybuilderresults"
         )
-        results = querybuilder(
+
+        querybuilder_parameters = dict(
             query=query,
             brains=True,
             b_start=b_start,
@@ -38,6 +48,15 @@ class QuerystringSearchPost(Service):
             limit=limit,
         )
 
+        # Exclude "self" content item from the results when ZCatalog supports NOT UUID
+        # queries and it is called on a content object.
+        if not IPloneSiteRoot.providedBy(self.context) and SUPPORT_NOT_UUID_QUERIES:
+            querybuilder_parameters.update(
+                dict(custom_query={"UID": {"not": self.context.UID()}})
+            )
+
+        results = querybuilder(**querybuilder_parameters)
+
         results = getMultiAdapter((results, self.request), ISerializeToJson)(
             fullobjects=fullobjects
         )
