@@ -148,6 +148,50 @@ def save_request_and_response_for_docs(name, response):
         resp.write(response.text)
 
 
+def save_request_for_docs(name, response):
+    if six.PY2:
+        open_kw = {}
+    else:
+        open_kw = {"newline": "\n"}
+    filename = "{}/{}".format(base_path, "%s.req" % name)
+    with open(filename, "w", **open_kw) as req:
+        req.write(
+            "{} {} HTTP/1.1\n".format(
+                response.request.method, response.request.path_url
+            )
+        )
+        ordered_request_headers = collections.OrderedDict(
+            sorted(response.request.headers.items())
+        )
+        for key, value in ordered_request_headers.items():
+            if key.lower() in REQUEST_HEADER_KEYS:
+                req.write("{}: {}\n".format(key.title(), value))
+        if response.request.body:
+            # If request has a body, make sure to set Content-Type header
+            if "content-type" not in REQUEST_HEADER_KEYS:
+                content_type = response.request.headers["Content-Type"]
+                req.write("Content-Type: %s\n" % content_type)
+
+            req.write("\n")
+
+            # Pretty print JSON request body
+            if content_type == "application/json":
+                json_body = json.loads(response.request.body)
+                body = pretty_json(json_body)
+                # Make sure Content-Length gets updated, just in case we
+                # ever decide to dump that header
+                response.request.prepare_body(data=body, files=None)
+
+            req.flush()
+            if isinstance(response.request.body, six.text_type) or not hasattr(
+                req, "buffer"
+            ):
+                req.write(response.request.body)
+            else:
+                req.buffer.seek(0, 2)
+                req.buffer.write(response.request.body)
+
+
 class TestDocumentationBase(unittest.TestCase):
     def setUp(self):
         self.statictime = self.setup_with_context_manager(StaticTime())
@@ -1342,10 +1386,18 @@ class TestDocumentation(TestDocumentationBase):
         )
         save_request_and_response_for_docs("querystringsearch_post", response)
 
+    def test_system_get(self):
+        response = self.api_session.get("/@system")
+        save_request_for_docs("system_get", response)
+
+    def test_database_get(self):
+        response = self.api_session.get("/@database")
+        save_request_for_docs("database_get", response)
+
 
 class TestDocumentationMessageTranslations(TestDocumentationBase):
 
-    layer = layer = PLONE_RESTAPI_DX_FUNCTIONAL_TESTING
+    layer = PLONE_RESTAPI_DX_FUNCTIONAL_TESTING
 
     def setUp(self):
         super(TestDocumentationMessageTranslations, self).setUp()
@@ -1536,16 +1588,60 @@ class TestCommenting(TestDocumentationBase):
         response = self.api_session.get("/front-page?expand=breadcrumbs,workflow")
         save_request_and_response_for_docs("expansion", response)
 
-    @unittest.skipIf(not PLONE5, "Just Plone 5 currently.")
+
+@unittest.skipIf(not PLONE5, "Just Plone 5 currently.")
+class TestControlPanelDocumentation(TestDocumentationBase):
+
+    layer = PLONE_RESTAPI_DX_FUNCTIONAL_TESTING
+
     def test_controlpanels_get_listing(self):
         response = self.api_session.get("/@controlpanels")
         save_request_and_response_for_docs("controlpanels_get", response)
 
-    @unittest.skipIf(not PLONE5, "Just Plone 5 currently.")
     def test_controlpanels_get_item(self):
         response = self.api_session.get("/@controlpanels/editing")
         save_request_and_response_for_docs("controlpanels_get_item", response)
 
+    def test_controlpanels_get_dexterity(self):
+        response = self.api_session.get("/@controlpanels/dexterity-types")
+        save_request_and_response_for_docs("controlpanels_get_dexterity", response)
+
+    def test_controlpanels_crud_dexterity(self):
+        # POST
+        response = self.api_session.post(
+            "/@controlpanels/dexterity-types",
+            json={
+                "title": "My Custom Content Type",
+                "description": "A custom content-type",
+            },
+        )
+        save_request_and_response_for_docs(
+            "controlpanels_post_dexterity_item", response
+        )
+
+        # GET
+        response = self.api_session.get(
+            "/@controlpanels/dexterity-types/my_custom_content_type"
+        )
+        save_request_and_response_for_docs("controlpanels_get_dexterity_item", response)
+
+        # PATCH
+        response = self.api_session.patch(
+            "/@controlpanels/dexterity-types/my_custom_content_type",
+            json={"title": "My Content Type", "description": "A content-type"},
+        )
+        save_request_and_response_for_docs(
+            "controlpanels_patch_dexterity_item", response
+        )
+
+        # DELETE
+        response = self.api_session.delete(
+            "/@controlpanels/dexterity-types/my_custom_content_type"
+        )
+        save_request_and_response_for_docs(
+            "controlpanels_delete_dexterity_item", response
+        )
+
 
 @unittest.skipUnless(
     PAM_INSTALLED, "plone.app.multilingual is installed by default only in Plone 5"
